# GGUI
GGUI is a graphical user interface for pygame with opengl.

Its a thin wrapper around these libs to provide basic tools to rende text, scrollable windows, buttons and dropdowns inside your pygame application.

It supports images, borders, antialiased text and text outlines, styles and style changes on hover and on click, transparency, toggles such as hide/show enable/disable, and uses lazy rendering for increased text rendering performance.

It also supports event-driven programming by firing click and select events through pypubsub.

## Usage

Basic usage is shown through example.py

More complete and advanced usage is showcased in a simple game, idle_game.py.

![Capture of the game](https://i.imgur.com/71GY887.png)
